> [!WARNING] 
> This is an unstable version. Changes may be backwards incompatible

# `py-pletyvo`

Implementation of the client and protocols of [the Pletyvo decentralized platform](https://pletyvo.osyah.com/) in Python.

## Install

```bash
pip install -U pletyvo
```
